summaryrefslogtreecommitdiff
path: root/src/mainboard/televideo/tc7020/irq_tables.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/mainboard/televideo/tc7020/irq_tables.c')
-rw-r--r--src/mainboard/televideo/tc7020/irq_tables.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/mainboard/televideo/tc7020/irq_tables.c b/src/mainboard/televideo/tc7020/irq_tables.c
index d31fa17700..f8af382b22 100644
--- a/src/mainboard/televideo/tc7020/irq_tables.c
+++ b/src/mainboard/televideo/tc7020/irq_tables.c
@@ -48,7 +48,7 @@
const struct irq_routing_table intel_irq_routing_table = {
PIRQ_SIGNATURE, /* u32 signature */
PIRQ_VERSION, /* u16 version */
- 32+16*IRQ_SLOT_COUNT, /* There can be a total of IRQ_SLOT_COUNT devices on the bus */
+ 32+16*CONFIG_IRQ_SLOT_COUNT, /* There can be a total of CONFIG_IRQ_SLOT_COUNT devices on the bus */
0x00, /* Where the interrupt router lies (bus) */
(0x12<<3)|0x0, /* Where the interrupt router lies (dev) */
EXCLUSIVE_PCI_IRQS, /* IRQs devoted exclusively to PCI usage */